==> core-react-0.8.0.tgz: package/es/Board/BoardHeader.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var rerangeChildren = function rerangeChildren(children) {
  if (!Array.isArray(children)) {
    return children;
  }

  var buttonList = [];
  var tabList = [];
  children.forEach(function (elem) {
    var _elem$type;

    // TODO elem.props.mdxType
    React.isValidElement(elem) && ((elem === null || elem === void 0 ? void 0 : (_elem$type = elem.type) === null || _elem$type === void 0 ? void 0 : _elem$type.name) === 'Button' ? buttonList : tabList).push(elem);
  });
  return tabList.concat(buttonList.reverse());
};

var BoardHeader = function BoardHeader(props) {
  var children = props.children,
      className = props.className,
      title = props.title,
      other = _objectWithoutProperties(props, ["children", "className", "title"]);

  return React.createElement("div", _extends({
    className: cx("".concat("waui", "-board__header"), "".concat("waui", "-board__header"), className)
  }, other), title && React.createElement("div", {
    className: "".concat("waui", "-board__header-title")
  }, title), rerangeChildren(children));
};

BoardHeader.propTypes = {
  children: PropTypes.any,
  className: PropTypes.string,

  /** The title of Board */
  title: PropTypes.string
};
export default BoardHeader;

==> core-react-0.8.2.tgz: package/es/Board/BoardHeader.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var rerangeChildren = function rerangeChildren(children) {
  if (!Array.isArray(children)) {
    return children;
  }

  var buttonList = [];
  var tabList = [];
  children.forEach(function (elem) {
    var _elem$type;

    // TODO elem.props.mdxType
    React.isValidElement(elem) && ((elem === null || elem === void 0 ? void 0 : (_elem$type = elem.type) === null || _elem$type === void 0 ? void 0 : _elem$type.name) === 'Button' ? buttonList : tabList).push(elem);
  });
  return tabList.concat(buttonList.reverse());
};

var BoardHeader = function BoardHeader(props) {
  var children = props.children,
      className = props.className,
      title = props.title,
      other = _objectWithoutProperties(props, ["children", "className", "title"]);

  return (/*#__PURE__*/React.createElement("div", _extends({
      className: cx("".concat("waui", "-board__header"), "".concat("waui", "-board__header"), className)
    }, other), title && /*#__PURE__*/React.createElement("div", {
      className: "".concat("waui", "-board__header-title")
    }, title), rerangeChildren(children))
  );
};

BoardHeader.propTypes = {
  children: PropTypes.any,
  className: PropTypes.string,

  /** The title of Board */
  title: PropTypes.string
};
export default BoardHeader;
